==> open-xchange-core_7.2.2.orig.tar.bz2: open-xchange-core-7.2.2/com.openexchange.server/src/com/openexchange/mail/cache/eventhandler/MailAccessEventHandler.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.cache.eventhandler;

import com.openexchange.caching.CacheElement;
import com.openexchange.caching.ElementEvent;
import com.openexchange.caching.ElementEventHandler;
import com.openexchange.mail.api.MailAccess;

/**
 * {@link MailAccessEventHandler} - The mail access event handler which preludes mail access closure if an instance of {@link MailAccess} is
 * removed from mail access cache.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class MailAccessEventHandler implements ElementEventHandler {

    /**
	 *
	 */
    private static final long serialVersionUID = 6568843006180170658L;

    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(MailAccessEventHandler.class));

    /**
     * Default constructor
     */
    public MailAccessEventHandler() {
        super();
    }

    /*
     * (non-Javadoc)
     * @see com.openexchange.cache.ElementEventHandlerWrapper#onExceededIdletimeBackground(org.apache.jcs.engine.control.event.ElementEvent)
     */
    @Override
    public void onExceededIdletimeBackground(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    /*
     * (non-Javadoc)
     * @see com.openexchange.cache.ElementEventHandlerWrapper#onExceededMaxlifeBackground(org.apache.jcs.engine.control.event.ElementEvent)
     */
    @Override
    public void onExceededMaxlifeBackground(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    /*
     * (non-Javadoc)
     * @see com.openexchange.cache.ElementEventHandlerWrapper#onSpooledDiskNotAvailable(org.apache.jcs.engine.control.event.ElementEvent)
     */
    @Override
    public void onSpooledDiskNotAvailable(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    /*
     * (non-Javadoc)
     * @see com.openexchange.cache.ElementEventHandlerWrapper#onSpooledNotAllowed(org.apache.jcs.engine.control.event.ElementEvent)
     */
    @Override
    public void onSpooledNotAllowed(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    /**
     * Closes given instance of {@link MailAccess}
     */
    private void close(final MailAccess<?, ?> mailAccess) {
        mailAccess.close(false);
    }

    @Override
    public void handleElementEvent(final ElementEvent event) {
        LOG.error("Unknown event type: " + event.getElementEvent());
    }

    @Override
    public void onExceededIdletimeOnRequest(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    @Override
    public void onExceededMaxlifeOnRequest(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    @Override
    public void onSpooledDiskAvailable(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }
}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.server/src/com/openexchange/mail/cache/eventhandler/MailAccessEventHandler.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.cache.eventhandler;

import com.openexchange.caching.CacheElement;
import com.openexchange.caching.ElementEvent;
import com.openexchange.caching.ElementEventHandler;
import com.openexchange.mail.api.MailAccess;

/**
 * {@link MailAccessEventHandler} - The mail access event handler which preludes mail access closure if an instance of {@link MailAccess} is
 * removed from mail access cache.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class MailAccessEventHandler implements ElementEventHandler {

    /**
	 *
	 */
    private static final long serialVersionUID = 6568843006180170658L;

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MailAccessEventHandler.class);

    /**
     * Default constructor
     */
    public MailAccessEventHandler() {
        super();
    }

    /*
     * (non-Javadoc)
     * @see com.openexchange.cache.ElementEventHandlerWrapper#onExceededIdletimeBackground(org.apache.jcs.engine.control.event.ElementEvent)
     */
    @Override
    public void onExceededIdletimeBackground(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    /*
     * (non-Javadoc)
     * @see com.openexchange.cache.ElementEventHandlerWrapper#onExceededMaxlifeBackground(org.apache.jcs.engine.control.event.ElementEvent)
     */
    @Override
    public void onExceededMaxlifeBackground(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    /*
     * (non-Javadoc)
     * @see com.openexchange.cache.ElementEventHandlerWrapper#onSpooledDiskNotAvailable(org.apache.jcs.engine.control.event.ElementEvent)
     */
    @Override
    public void onSpooledDiskNotAvailable(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    /*
     * (non-Javadoc)
     * @see com.openexchange.cache.ElementEventHandlerWrapper#onSpooledNotAllowed(org.apache.jcs.engine.control.event.ElementEvent)
     */
    @Override
    public void onSpooledNotAllowed(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    /**
     * Closes given instance of {@link MailAccess}
     */
    private void close(final MailAccess<?, ?> mailAccess) {
        mailAccess.close(false);
    }

    @Override
    public void handleElementEvent(final ElementEvent event) {
        LOG.error("Unknown event type: {}", event.getElementEvent());
    }

    @Override
    public void onExceededIdletimeOnRequest(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    @Override
    public void onExceededMaxlifeOnRequest(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }

    @Override
    public void onSpooledDiskAvailable(final ElementEvent event) {
        final CacheElement cacheElem = (CacheElement) event.getSource();
        close((MailAccess<?, ?>) cacheElem.getVal());
    }
}
